@@ -4,22 +4,22 @@ use strict;
 use warnings;
 use utf8;
 
-use Archive::Extract;
-use Archive::Tar;
-use CPAN::Meta;
-use File::Basename qw(dirname basename);
-use File::Copy qw(copy);
-use File::Find qw(find);
-use File::Path qw(mkpath);
-use File::Spec;
-use File::Temp qw(tempdir);
-use File::pushd;
-use HTTP::Tiny;
-use MetaCPAN::Client;
+use Archive::Extract ();
+use Archive::Tar     qw( COMPRESS_GZIP );
+use CPAN::Meta       ();
+use File::Basename   qw( basename dirname );
+use File::Copy       qw( copy );
+use File::Find       qw( find );
+use File::Path       qw( mkpath );
+use File::Spec       ();
+use File::Temp       qw( tempdir );
+use File::pushd      qw( pushd );
+use HTTP::Tiny       ();
+use MetaCPAN::Client ();
 
 sub new {
     my $class = shift;
-    my %args = @_ == 1 ? %{ $_[0] } : @_;
+    my %args  = @_ == 1 ? %{ $_[0] } : @_;
     unless ( exists $args{directory} ) {
         Carp::croak("Missing directory");
     }
@@ -35,7 +35,7 @@ sub inject {
     my ( $self, $source, $opts ) = @_;
     local $self->{author}
         = $opts->{author} || $self->{author} || 'DUMMY';
-    local $self->{author_subdir} = $opts->{author_subdir} || '';
+    local $self->{author_subdir} = $opts->{author_subdir} || q{};
 
     my $tarpath;
     if ( $source =~ /(?:^git(?:\+\w+)?:|\.git(?:@.+)?$)/ )
@@ -99,7 +99,7 @@ sub tarpath {
 sub _detect_author {
     my ( $self, $source, $archive ) = @_;
     my $tmpdir = tempdir( CLEANUP => 1 );
-    my $ae = Archive::Extract->new( archive => $archive );
+    my $ae     = Archive::Extract->new( archive => $archive );
     $ae->extract( to => $tmpdir );
     my $guard = pushd( glob("$tmpdir/*") );
     $self->{author}->($source);
